@@ -4,7 +4,7 @@ pub type N = usize;
 pub type Z = isize;
 
 pub type R = f64;
-pub type C = num::complex::Complex<R>;
+pub type C = num_complex::Complex<R>;
 
 pub type M1 = [C; 4];
 pub type M2 = [C; 16];
\ No newline at end of file
